@@ -1,6 +1,6 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
-# Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta, 
+# Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta,
 #			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,6 @@
 
 ## provide some interfaces to our C implementations
 
-
 ## t in Matrix is now faster
 ##setMethod("t", signature(x = "ngCMatrix"),
 ##    function(x) .Call(R_transpose_ngCMatrix, x))
@@ -30,29 +29,30 @@
 ## easily as there are too many signatures to overload.
 
 
-## density for ngC/dgCMatrix 
-.density_Matrix <- function(x) length(x@i)/prod(dim(x))
+## density for ngC/dgCMatrix
+.density_Matrix <- function(x)
+  length(x@i) / prod(dim(x))
 
 ## helper to convert names into an integer index
 .translate_index <- function(i, labels, n) {
-  
   ## checking is deferred to the actual subsetting code
-  if(is.logical(i)) return(which(i))
+  if (is.logical(i))
+    return(which(i))
   
-  if(is.numeric(i)) {
+  if (is.numeric(i)) {
     ## deal with neg. and 0's
-    if(all(i>0)) return(as.integer(i))
-    else return(seq(n)[i])
+    if (all(i > 0))
+      return(as.integer(i))
+    else
+      return(seq(n)[i])
   }
   
   ## if no labels were specified we used "1", "2", etc.
-  if(is.null(labels)) labels <- seq(n)
+  if (is.null(labels))
+    labels <- seq(n)
   sel <- structure(seq(length(labels)), names = labels)[i]
   
-  if(any(is.na(sel))) stop("subscript out of bounds")
+  if (any(is.na(sel)))
+    stop("subscript out of bounds")
   sel
 }
-
-
-
-###
